==> nextcloud-app-news-1:25.1.0-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/news/l10n/es_MX.js <==
OC.L10N.register(
    "news",
    {
    "Request failed, network connection unavailable!" : "¡Se presentó una falla en la solicitud, la conexión a la red no está disponible!",
    "Request unauthorized. Are you logged in?" : "Solicitud no autorizada. ¿Has iniciado sesisón?",
    "Request forbidden. Are you an administrator?" : "Solicitud prohibida. ¿Es un administrador?",
    "Token expired or app not enabled! Reload the page!" : "¡La ficha expiró o la aplicación no está habilitada! ¡Por favor recarga la página!",
    "Internal server error! Please check your data/nextcloud.log file for additional information!" : "¡Se presentó un error interno del servidor! ¡Por favor verifica el archivo data/nextcloud.log para más informacón!",
    "Request failed, Nextcloud is in currently in maintenance mode!" : "¡Se presentó una falla en la solicitud, por el momento Nextcloud se encuentra en modo mantenimiento!",
    "News feeds" : "Fuentes de noticias",
    "Unread articles" : "Artículos sin leer",
    "News" : "Noticias",
    "News folders" : "Carpetas de noticias",
    "News articles" : "Artículos de noticias",
    "Shared with me" : "Compartido conmigo",
    "An RSS/Atom feed reader" : "Un lector de fuentes RSS/Atom",
    "Download" : "Descargar",
    "Close" : "Cerrar",
    "Web address" : "Dirección web",
    "No folder" : "No hay carpetas",
    "Folder name" : "Nombre de la carpeta",
    "Username" : "Usuario",
    "Password" : "Contraseña",
    "Feed exists already!" : "¡La fuente ya existe!",
    "New folder" : "Carpeta nueva ",
    "Folder exists already!" : "¡La carpeta ya existe!",
    "HTTP Basic Auth credentials must be stored unencrypted! Everyone with access to the server or database will be able to access them!" : "¡Las credenciales HTTP Basic Auth deben ser almacenadas decriptadas! ¡Todos aquellos que tengan acceso al servidor o a la base de datos tendrán acceso a ellas!",
    "Credentials" : "Credenciales",
    "Auto discover Feed" : "Descubrir la fuente automáticamente",
    "Subscribe" : "Suscribir",
    "Last job execution ran {relativeTime}. Something seems wrong." : "La última ejecución del trabajo fue hace {relativeTime}. Algo parece estar mal. ",
    "Last job ran {relativeTime}." : "El último trabajo se ejecutó {relativeTime}.",
    "Maximum read count per feed" : "Conteo máximo de lecturas por fuente",
    "Maximum redirects" : "Redirecciones máximas",
    "Feed fetcher timeout" : "Tiempo de vida para el buscador de fuentes",
    "Explore Service URL" : "Explorar la URL del Servicio",
    "Update interval" : "Intervalo de actualización",
    "Successfully updated news configuration" : "Configuración de noticias actualizada exitosamente",
    "Unable to update news config" : "No se pudo actualizar la configuración de noticias",
    "Use system cron for updates" : "Usa el cron del sistema para las actualizaciones",
    "Disable this if you use a custom updater." : "Deshabilite esto si utiliza un actualizador personalizado.",
    "Defines the maximum amount of articles that can be read per feed which will not be deleted by the cleanup job; if old articles reappear after being read, increase this value; negative values such as -1 will turn this feature off." : "Define la cantidad máxima de artículos que se pueden leer por fuente y que no serán eliminados por el trabajo de limpieza; si artículos antiguos vuelven a aparecer después de ser leídos, aumente este valor; valores negativos, como -1, desactivarán esta característica.",
    "Delete unread articles automatically" : "Eliminar los artículos no leídos automáticamente",
    "Enable this if you also want to delete unread articles." : "Habilite esto si además desea eliminar los artículos no leídos.",
    "How many redirects the feed fetcher should follow." : "Cuántas redirecciones debería seguir el buscador de fuentes.",
    "Maximum number of seconds to wait for an RSS or Atom feed to load; if it takes longer the update will be aborted." : "Tiempo máximo en segundos para esperar a que cargue una fuente RSS o Atom; si tarda más, se abortará la actualización.",
    "Interval in seconds in which the feeds will be updated." : "Intervalo en segundos en el que se actualizarán las fuentes.",
    "No article selected" : "Ningún artículo seleccionado",
    "Please select an article from the list..." : "Por favor, seleccione un artículo de la lista...",
    "Move feed to folder" : "Mover fuente a la carpeta",
    "Move" : "Mover",
    "User Name" : "Nombre de usuario",
    "Share" : "Compartir",
    "Share with" : "Compartir con",
    "Share with {num} users" : "Compartir con {num} usuarios",
    "Mark read" : "Marcar como leído",
    "All articles" : "Todos los artículos",
    "Starred" : "Marcados",
    "Explore" : "Explorar",
    "Settings" : "Configuraciones ",
    "Keyboard shortcuts" : "Atajos del teclado",
    "Disable mark read through scrolling" : "Deshabilitar el marcar como leído al desplazar",
    "Compact view" : "Vista compacta",
    "Show all articles" : "Mostrar todos los artículos",
    "Reverse ordering (oldest on top)" : "Orden inverso (más antiguo arriba)",
    "Rename Folder" : "Renombrar carpeta",
    "Are you sure you want to delete?" : "¿Está seguro que quiere eliminarlo?",
    "Rename" : "Renombrar",
    "Delete" : "Borrar",
    "Open Feed URL" : "Abrir URL de la fuente",
    "Rename Feed" : "Renombrar la Fuente",
    "Unpin from top" : "Desanclar a la parte superior",
    "Pin to top" : "Anclar a la parte superior",
    "Newest first" : "Más reciente primero",
    "Oldest first" : "Más antiguo primero",
    "Default order" : "Ordenamiento predeterminado",
    "Enable full text" : "Habilitar texto completo",
    "Disable full text" : "Deshabilitar texto completo",
    "Unread updated" : "No-leídos actualizados",
    "Ignore updated" : "Ignorar actualizados",
    "Share within Instance" : "Compartir dentro de la instancia",
    "Toggle star article" : "Alternar artículos marcados",
    "Close details" : "Cerrar detalles",
    "by" : "por",
    "from" : "de",
    "shared by" : "compartido por",
    "Play audio" : "Reproducir audio",
    "Download audio" : "Descargar audio",
    "Download video" : "Descargar video",
    "Open website" : "Abrir sitio web",
    "Keep article unread" : "Mantener el artículo como no-leído",
    "Toggle keep current article unread" : "Alternar mantener artículo actual como no leído",
    "Remove keep article unread" : "Eliminar mantener artículo como no leído",
    "{num} seconds" : "{num} segundos",
    "{num} minutes ago" : "Hace {num} minutos",
    "{num} hours ago" : "Hace {num} horas",
    "{num} days ago" : "Hace {num} días",
    "{num} months ago" : "Hace {num} meses",
    "{num} years ago" : "Hace {num} años",
    "Keyboard shortcut" : "Atajo del teclado",
    "Action" : "Acción",
    "right" : "derecha",
    "Jump to next article" : "Ir al artículo siguiente ",
    "left" : "izquierda",
    "Jump to previous article" : "Ir al artículo anterior",
    "Star article and jump to next one" : "Marcar el artículo y continuar al siguiente",
    "Open article in new tab" : "Abrir el artículo en una nueva pestaña",
    "Refresh" : "Actualizar",
    "Load next feed" : "Cargar la siguiente fuente ",
    "Load previous feed" : "Cargar fuente anterior",
    "Load previous folder" : "Cargar carpeta anterrior",
    "Load next folder" : "Cargar la siguiente carpeta",
    "Scroll to active navigation entry" : "Desplázate hasta el elemento de navegación activo",
    "Shift" : "Mayús",
    "All Articles" : "Todos los artículos",
    "No feeds found to add" : "No se encontraron fuentes para añadir",
    "Subscribe to" : "Suscribirse a",
    "Unread Articles" : "Artículos sin leer",
    "If given, this service" : "Si se indica, este servicio",
    "Ajax or webcron mode detected! Your feeds will not be updated!" : "¡Se ha detectado el modo Ajax o webron! ¡Tus fuentes no serán actualizadas!",
    "How to set up the operating system cron" : "Cómo establecer las tareas programadas del sistema operativo",
    "Install and set up a faster parallel updater that uses the News app's update API" : "Instala y configura un actualizador en paralelo más rápido que use el API de actualización de la nueva aplicación",
    "No articles available" : "No hay artículos disponibles",
    "No unread articles available" : "No hay artículos sin leer disponibles",
    "Star article" : "Marcar el artículo",
    "Unstar article" : "Desmarcar artículo",
    "Share with users" : "Compartir con usuarios",
    "No users found" : "No se encontraron usuarios",
    "Error while searching for users" : "Error al buscar usuarios",
    "Share on social media" : "Compartir en redes sociales",
    "I wanted you to see this article" : "Quería que viera este artículo",
    "Check out this article" : "Mire este artículo",
    "Description" : "Descripción",
    "Toggle expand article in compact view" : "Alternar expandir artículo en vista compacta",
    "Mark current article's feed/folder read" : "Marcar la fuente/carpeta del artículo actual como leído",
    "Folder" : "Carpeta",
    "Go back" : "Regresar",
    "New Folder" : "Carpeta Nueva",
    "Create" : "Crear",
    "Update failed more than 50 times" : "La carga falló más de 50 veces",
    "Deleted feed" : "Borrar fuente",
    "Undo delete feed" : "Deshacer borrar fuente",
    "Menu" : "Menú",
    "Open feed URL" : "Abrir URL de la fuente",
    "Dismiss" : "Descartar",
    "Collapse" : "Colapsar",
    "Deleted folder" : "Borrar carpeta",
    "Undo delete folder" : "Deshacer borrar carpeta",
    "Expand articles on key navigation" : "Expandir artículos al navegar con el teclado",
    "Subscriptions (OPML)" : "Suscripciones (OPML)",
    "Import" : "Importar",
    "Export" : "Exportar",
    "Error when importing: File does not contain valid OPML" : "Se presentó un error al importar: El archivo no contiene un OPML válido",
    "Error when importing: OPML is does neither contain feeds nor folders" : "Se presentó un error al importar: OPML no contiene fuentes o carpetas",
    "Unread/Starred Articles" : "Artículos No Leídos/Marcados",
    "Error when importing: file does not contain valid JSON" : "Se presentó un error al importar: el archivo no contiene un JSON válido",
    "Help" : "Ayuda",
    "Documentation" : "Documentación",
    "Report a bug" : "Reportar una falla"
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");

==> nextcloud-app-news-1:26.0.1-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/news/l10n/es_MX.js <==
OC.L10N.register(
    "news",
    {
    "News feeds" : "Fuentes de noticias",
    "Unread articles" : "Artículos sin leer",
    "News" : "Noticias",
    "News folders" : "Carpetas de noticias",
    "News articles" : "Artículos de noticias",
    "Shared with me" : "Compartido conmigo",
    "An RSS/Atom feed reader" : "Un lector de fuentes RSS/Atom",
    "Download" : "Descargar",
    "Close" : "Cerrar",
    "Web address" : "Dirección web",
    "No folder" : "No hay carpetas",
    "Folder name" : "Nombre de la carpeta",
    "Username" : "Usuario",
    "Password" : "Contraseña",
    "Feed exists already!" : "¡La fuente ya existe!",
    "New folder" : "Carpeta nueva ",
    "Folder exists already!" : "¡La carpeta ya existe!",
    "HTTP Basic Auth credentials must be stored unencrypted! Everyone with access to the server or database will be able to access them!" : "¡Las credenciales HTTP Basic Auth deben ser almacenadas decriptadas! ¡Todos aquellos que tengan acceso al servidor o a la base de datos tendrán acceso a ellas!",
    "Credentials" : "Credenciales",
    "Auto discover Feed" : "Descubrir la fuente automáticamente",
    "Subscribe" : "Suscribir",
    "Successfully updated news configuration" : "Configuración de noticias actualizada exitosamente",
    "Unable to update news config" : "No se pudo actualizar la configuración de noticias",
    "Last job execution ran {relativeTime}. Something seems wrong." : "La última ejecución del trabajo fue hace {relativeTime}. Algo parece estar mal. ",
    "Last job ran {relativeTime}." : "El último trabajo se ejecutó {relativeTime}.",
    "Maximum read count per feed" : "Conteo máximo de lecturas por fuente",
    "Maximum redirects" : "Redirecciones máximas",
    "Feed fetcher timeout" : "Tiempo de vida para el buscador de fuentes",
    "Explore Service URL" : "Explorar la URL del Servicio",
    "Update interval" : "Intervalo de actualización",
    "Use system cron for updates" : "Usa el cron del sistema para las actualizaciones",
    "Disable this if you use a custom updater." : "Deshabilite esto si utiliza un actualizador personalizado.",
    "Defines the maximum amount of articles that can be read per feed which will not be deleted by the cleanup job; if old articles reappear after being read, increase this value; negative values such as -1 will turn this feature off." : "Define la cantidad máxima de artículos que se pueden leer por fuente y que no serán eliminados por el trabajo de limpieza; si artículos antiguos vuelven a aparecer después de ser leídos, aumente este valor; valores negativos, como -1, desactivarán esta característica.",
    "Delete unread articles automatically" : "Eliminar los artículos no leídos automáticamente",
    "Enable this if you also want to delete unread articles." : "Habilite esto si además desea eliminar los artículos no leídos.",
    "How many redirects the feed fetcher should follow." : "Cuántas redirecciones debería seguir el buscador de fuentes.",
    "Maximum number of seconds to wait for an RSS or Atom feed to load; if it takes longer the update will be aborted." : "Tiempo máximo en segundos para esperar a que cargue una fuente RSS o Atom; si tarda más, se abortará la actualización.",
    "Interval in seconds in which the feeds will be updated." : "Intervalo en segundos en el que se actualizarán las fuentes.",
    "No article selected" : "Ningún artículo seleccionado",
    "Please select an article from the list..." : "Por favor, seleccione un artículo de la lista...",
    "Move" : "Mover",
    "User Name" : "Nombre de usuario",
    "Share" : "Compartir",
    "Share with" : "Compartir con",
    "Share with {num} users" : "Compartir con {num} usuarios",
    "Default" : "Por omisión",
    "Vertical" : "Vertical",
    "Horizontal" : "Horizontal",
    "Off" : "Desactivado",
    "Rename Folder" : "Renombrar carpeta",
    "Are you sure you want to delete?" : "¿Está seguro que quiere eliminarlo?",
    "Mark read" : "Marcar como leído",
    "All articles" : "Todos los artículos",
    "Starred" : "Marcados",
    "Explore" : "Explorar",
    "Settings" : "Configuraciones ",
    "Documentation" : "Documentación",
    "Keyboard shortcuts" : "Atajos del teclado",
    "Disable mark read through scrolling" : "Deshabilitar el marcar como leído al desplazar",
    "Show all articles" : "Mostrar todos los artículos",
    "Reverse ordering (oldest on top)" : "Orden inverso (más antiguo arriba)",
    "Rename" : "Renombrar",
    "Delete" : "Borrar",
    "Rename Feed" : "Renombrar la Fuente",
    "Open Feed URL" : "Abrir URL de la fuente",
    "Unpin from top" : "Desanclar a la parte superior",
    "Pin to top" : "Anclar a la parte superior",
    "Newest first" : "Más reciente primero",
    "Oldest first" : "Más antiguo primero",
    "Default order" : "Ordenamiento predeterminado",
    "Enable full text" : "Habilitar texto completo",
    "Disable full text" : "Deshabilitar texto completo",
    "Previous" : "Previo",
    "Share within Instance" : "Compartir dentro de la instancia",
    "Toggle star article" : "Alternar artículos marcados",
    "Close details" : "Cerrar detalles",
    "shared by" : "compartido por",
    "by" : "por",
    "Play audio" : "Reproducir audio",
    "Download audio" : "Descargar audio",
    "Download video" : "Descargar video",
    "Open website" : "Abrir sitio web",
    "Keep article unread" : "Mantener el artículo como no-leído",
    "Toggle keep current article unread" : "Alternar mantener artículo actual como no leído",
    "Remove keep article unread" : "Eliminar mantener artículo como no leído",
    "Not available" : "No disponible",
    "Please wait" : "Por favor aguarda",
    "Keyboard shortcut" : "Atajo del teclado",
    "Action" : "Acción",
    "Jump to next article" : "Ir al artículo siguiente ",
    "Jump to previous article" : "Ir al artículo anterior",
    "right" : "derecha",
    "left" : "izquierda",
    "Star article and jump to next one" : "Marcar el artículo y continuar al siguiente",
    "Open article in new tab" : "Abrir el artículo en una nueva pestaña",
    "Refresh" : "Actualizar",
    "Load next feed" : "Cargar la siguiente fuente ",
    "Load previous feed" : "Cargar fuente anterior",
    "Load previous folder" : "Cargar carpeta anterrior",
    "Load next folder" : "Cargar la siguiente carpeta",
    "Scroll to active navigation entry" : "Desplázate hasta el elemento de navegación activo",
    "Shift" : "Mayús",
    "All Articles" : "Todos los artículos",
    "No feeds found to add" : "No se encontraron fuentes para añadir",
    "Subscribe to" : "Suscribirse a",
    "Unread Articles" : "Artículos sin leer",
    "If given, this service" : "Si se indica, este servicio",
    "Ajax or webcron mode detected! Your feeds will not be updated!" : "¡Se ha detectado el modo Ajax o webron! ¡Tus fuentes no serán actualizadas!",
    "How to set up the operating system cron" : "Cómo establecer las tareas programadas del sistema operativo",
    "Install and set up a faster parallel updater that uses the News app's update API" : "Instala y configura un actualizador en paralelo más rápido que use el API de actualización de la nueva aplicación"
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
